==> camel-k-model-v1-5.3.0-sources.jar: io/fabric8/camelk/v1/ConfigurationSpecBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigurationSpecBuilder extends ConfigurationSpecFluentImpl<ConfigurationSpecBuilder> implements VisitableBuilder<ConfigurationSpec,ConfigurationSpecBuilder> {

    ConfigurationSpecFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigurationSpecBuilder() {
        this(true);
    }

    public ConfigurationSpecBuilder(Boolean validationEnabled) {
        this(new ConfigurationSpec(), validationEnabled);
    }

    public ConfigurationSpecBuilder(ConfigurationSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public ConfigurationSpecBuilder(ConfigurationSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ConfigurationSpec(), validationEnabled);
    }

    public ConfigurationSpecBuilder(ConfigurationSpecFluent<?> fluent,ConfigurationSpec instance) {
        this(fluent, instance, true);
    }

    public ConfigurationSpecBuilder(ConfigurationSpecFluent<?> fluent,ConfigurationSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withType(instance.getType()); 
        fluent.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigurationSpecBuilder(ConfigurationSpec instance) {
        this(instance,true);
    }

    public ConfigurationSpecBuilder(ConfigurationSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withType(instance.getType()); 
        this.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.camelk.v1.EditableConfigurationSpec build() {
        EditableConfigurationSpec buildable = new EditableConfigurationSpec(fluent.getType(),fluent.getValue());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ConfigurationSpecBuilder that = (ConfigurationSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> camel-k-model-v1-5.3.1-sources.jar: io/fabric8/camelk/v1/ConfigurationSpecBuilder.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigurationSpecBuilder extends ConfigurationSpecFluentImpl<ConfigurationSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<ConfigurationSpec,ConfigurationSpecBuilder> {

    ConfigurationSpecFluent<?> fluent;
    Boolean validationEnabled;

    public ConfigurationSpecBuilder() {
        this(true);
    }

    public ConfigurationSpecBuilder(Boolean validationEnabled) {
        this(new ConfigurationSpec(), validationEnabled);
    }

    public ConfigurationSpecBuilder(ConfigurationSpecFluent<?> fluent) {
        this(fluent, true);
    }

    public ConfigurationSpecBuilder(ConfigurationSpecFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ConfigurationSpec(), validationEnabled);
    }

    public ConfigurationSpecBuilder(ConfigurationSpecFluent<?> fluent,ConfigurationSpec instance) {
        this(fluent, instance, true);
    }

    public ConfigurationSpecBuilder(ConfigurationSpecFluent<?> fluent,ConfigurationSpec instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withType(instance.getType()); 
        fluent.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public ConfigurationSpecBuilder(ConfigurationSpec instance) {
        this(instance,true);
    }

    public ConfigurationSpecBuilder(ConfigurationSpec instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withType(instance.getType()); 
        this.withValue(instance.getValue()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.camelk.v1.EditableConfigurationSpec build() {
        EditableConfigurationSpec buildable = new EditableConfigurationSpec(fluent.getType(),fluent.getValue());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ConfigurationSpecBuilder that = (ConfigurationSpecBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
